firebase_blocsync_authentication_provider library
An authentication provider for Blocsync that uses Firebase Authentication
Classes
- FirebaseBlocsyncAuthenticationProvider
- An authentication provider for Blocsync that uses Firebase Authentication
An authentication provider for Blocsync that uses Firebase Authentication